@@ -7,16 +7,16 @@
 
 #include <QTest>
 
-#include "kimaptest/fakeserver.h"
-#include "kimap/session.h"
 #include "kimap/fetchjob.h"
+#include "kimap/session.h"
+#include "kimaptest/fakeserver.h"
 
-#include <QTest>
 #include <QSignalSpy>
+#include <QTest>
 
 Q_DECLARE_METATYPE(KIMAP::FetchJob::FetchScope)
 
-class FetchJobTest: public QObject
+class FetchJobTest : public QObject
 {
     Q_OBJECT
 
@@ -38,7 +38,7 @@ private:
     QMap<qint64, KIMAP::Message> m_msgs;
 
 public Q_SLOTS:
-    void onHeadersReceived(const QString &/*mailBox*/,
+    void onHeadersReceived(const QString & /*mailBox*/,
                            const QMap<qint64, qint64> &uids,
                            const QMap<qint64, qint64> &sizes,
                            const QMap<qint64, KIMAP::MessageAttribute> &attrs,
@@ -53,7 +53,7 @@ public Q_SLOTS:
         m_attrs.unite(attrs);
     }
 
-    void onMessagesReceived(const QString &/*mailbox*/,
+    void onMessagesReceived(const QString & /*mailbox*/,
                             const QMap<qint64, qint64> &uids,
                             const QMap<qint64, KIMAP::MessageAttribute> &attrs,
                             const QMap<qint64, KIMAP::MessagePtr> &messages)
@@ -64,8 +64,8 @@ public Q_SLOTS:
         m_attrs.unite(attrs);
     }
 
-    void onPartsReceived(const QString &/*mailbox*/,
-                         const QMap<qint64, qint64> &/*uids*/,
+    void onPartsReceived(const QString & /*mailbox*/,
+                         const QMap<qint64, qint64> & /*uids*/,
                          const QMap<qint64, KIMAP::MessageAttribute> &attrs,
                          const QMap<qint64, KIMAP::MessageParts> &parts)
     {
@@ -98,29 +98,25 @@ private Q_SLOTS:
         scope.changedSince = 123456789;
 
         QList<QByteArray> scenario;
-        scenario << FakeServer::preauth()
-                 << "C: A000001 FETCH 1:4 (FLAGS UID) (CHANGEDSINCE 123456789)"
+        scenario << FakeServer::preauth() << "C: A000001 FETCH 1:4 (FLAGS UID) (CHANGEDSINCE 123456789)"
                  << "S: * 1 FETCH ( FLAGS () UID 1 )"
                  << "S: * 2 FETCH ( FLAGS () UID 2 )"
                  << "S: * 3 FETCH ( FLAGS () UID 3 )"
                  << "S: * 4 FETCH ( FLAGS () UID 4 )"
                  << "S: A000001 OK fetch done";
 
-        QTest::newRow("messages have empty flags (with changedsince)") << false << KIMAP::ImapSet(1, 4) << 4
-                << scenario << scope << KIMAP::ImapSet{};
+        QTest::newRow("messages have empty flags (with changedsince)") << false << KIMAP::ImapSet(1, 4) << 4 << scenario << scope << KIMAP::ImapSet{};
 
         scenario.clear();
         scope.changedSince = 0;
-        scenario << FakeServer::preauth()
-                 << "C: A000001 FETCH 1:4 (FLAGS UID)"
+        scenario << FakeServer::preauth() << "C: A000001 FETCH 1:4 (FLAGS UID)"
                  << "S: * 1 FETCH ( FLAGS () UID 1 )"
                  << "S: * 2 FETCH ( FLAGS () UID 2 )"
                  << "S: * 3 FETCH ( FLAGS () UID 3 )"
                  << "S: * 4 FETCH ( FLAGS () UID 4 )"
                  << "S: A000001 OK fetch done";
 
-        QTest::newRow("messages have empty flags") << false << KIMAP::ImapSet(1, 4) << 4
-                << scenario << scope << KIMAP::ImapSet{};
+        QTest::newRow("messages have empty flags") << false << KIMAP::ImapSet(1, 4) << 4 << scenario << scope << KIMAP::ImapSet{};
 
         scenario.clear();
         // kill the connection part-way through a list, with carriage returns at end
@@ -128,8 +124,11 @@ private Q_SLOTS:
         // this should fail, but it shouldn't crash
         scenario << FakeServer::preauth()
                  << "C: A000001 FETCH 11 (RFC822.SIZE INTERNALDATE BODY.PEEK[HEADER.FIELDS (TO FROM MESSAGE-ID REFERENCES IN-REPLY-TO SUBJECT DATE)] FLAGS UID)"
-                 << "S: * 11 FETCH (RFC822.SIZE 770 INTERNALDATE \"11-Oct-2010 03:33:50 +0100\" BODY[HEADER.FIELDS (TO FROM MESSAGE-ID REFERENCES IN-REPLY-TO SUBJECT DATE)] {246}"
-                 << "S: From: John Smith <jonathanr.smith@foobarbaz.com>\r\nTo: \"amagicemailaddress@foobarbazbarfoo.com\"\r\n\t<amagicemailaddress@foobarbazbarfoo.com>\r\nDate: Mon, 11 Oct 2010 03:34:48 +0100\r\nSubject: unsubscribe\r\nMessage-ID: <ASDFFDSASDFFDS@foobarbaz.com>\r\n\r\n"
+                 << "S: * 11 FETCH (RFC822.SIZE 770 INTERNALDATE \"11-Oct-2010 03:33:50 +0100\" BODY[HEADER.FIELDS (TO FROM MESSAGE-ID REFERENCES IN-REPLY-TO "
+                    "SUBJECT DATE)] {246}"
+                 << "S: From: John Smith <jonathanr.smith@foobarbaz.com>\r\nTo: "
+                    "\"amagicemailaddress@foobarbazbarfoo.com\"\r\n\t<amagicemailaddress@foobarbazbarfoo.com>\r\nDate: Mon, 11 Oct 2010 03:34:48 "
+                    "+0100\r\nSubject: unsubscribe\r\nMessage-ID: <ASDFFDSASDFFDS@foobarbaz.com>\r\n\r\n"
                  << "X";
         scope.mode = KIMAP::FetchJob::FetchScope::Headers;
         QTest::newRow("connection drop") << false << KIMAP::ImapSet(11, 11) << 1 << scenario << scope << KIMAP::ImapSet{};
@@ -138,7 +137,8 @@ private Q_SLOTS:
         // Important bit here if "([127.0.0.1])" which used to crash the stream parser
         scenario << FakeServer::preauth()
                  << "C: A000001 FETCH 11 (RFC822.SIZE INTERNALDATE BODY.PEEK[HEADER.FIELDS (TO FROM MESSAGE-ID REFERENCES IN-REPLY-TO SUBJECT DATE)] FLAGS UID)"
-                 << "S: * 11 FETCH (RFC822.SIZE 770 INTERNALDATE \"11-Oct-2010 03:33:50 +0100\" BODY[HEADER.FIELDS (TO FROM MESSAGE-ID REFERENCES IN-REPLY-TO SUBJECT DATE)] {246}"
+                 << "S: * 11 FETCH (RFC822.SIZE 770 INTERNALDATE \"11-Oct-2010 03:33:50 +0100\" BODY[HEADER.FIELDS (TO FROM MESSAGE-ID REFERENCES IN-REPLY-TO "
+                    "SUBJECT DATE)] {246}"
                  << "S: ([127.0.0.1])\r\nDate: Mon, 11 Oct 2010 03:34:48 +0100\r\nSubject: unsubscribe\r\nMessage-ID: <ASDFFDSASDFFDS@foobarbaz.com>\r\n\r\n"
                  << "X";
         scope.mode = KIMAP::FetchJob::FetchScope::Headers;
@@ -155,20 +155,18 @@ private Q_SLOTS:
         QTest::newRow("buffer overwrite 2") << false << KIMAP::ImapSet(11, 11) << 1 << scenario << scope << KIMAP::ImapSet{};
 
         scenario.clear();
-        scenario << FakeServer::preauth()
-                 << "C: A000001 FETCH 11 (RFC822.SIZE INTERNALDATE BODY.PEEK[HEADER] FLAGS UID) (CHANGEDSINCE 123456789)"
+        scenario << FakeServer::preauth() << "C: A000001 FETCH 11 (RFC822.SIZE INTERNALDATE BODY.PEEK[HEADER] FLAGS UID) (CHANGEDSINCE 123456789)"
                  << "S: * 11 FETCH (UID 123 RFC822.SIZE 770 INTERNALDATE \"11-Oct-2010 03:33:50 +0100\" BODY[HEADER] {245}"
-                 << "S: From: John Smith <jonathanr.smith@foobarbaz.com>\r\nTo: \"amagicemailaddress@foobarbazbarfoo.com\"\r\n\t<amagicemailaddress@foobarbazbarfoo.com>\r\nDate: Mon, 11 Oct 2010 03:34:48 +0100\r\nSubject: unsubscribe\r\nMessage-ID: <ASDFFDSASDFFDS@foobarbaz.com>\r\n\r\n  FLAGS ())"
+                 << "S: From: John Smith <jonathanr.smith@foobarbaz.com>\r\nTo: "
+                    "\"amagicemailaddress@foobarbazbarfoo.com\"\r\n\t<amagicemailaddress@foobarbazbarfoo.com>\r\nDate: Mon, 11 Oct 2010 03:34:48 "
+                    "+0100\r\nSubject: unsubscribe\r\nMessage-ID: <ASDFFDSASDFFDS@foobarbaz.com>\r\n\r\n  FLAGS ())"
                  << "S: A000001 OK fetch done";
         scope.mode = KIMAP::FetchJob::FetchScope::FullHeaders;
         scope.changedSince = 123456789;
-        QTest::newRow("fetch full headers") << false << KIMAP::ImapSet(11, 11) << 1
-                                            << scenario << scope << KIMAP::ImapSet{};
-
+        QTest::newRow("fetch full headers") << false << KIMAP::ImapSet(11, 11) << 1 << scenario << scope << KIMAP::ImapSet{};
 
         scenario.clear();
-        scenario << FakeServer::preauth()
-                 << "C: A000001 UID FETCH 300:500 (FLAGS UID) (CHANGEDSINCE 12345 VANISHED)"
+        scenario << FakeServer::preauth() << "C: A000001 UID FETCH 300:500 (FLAGS UID) (CHANGEDSINCE 12345 VANISHED)"
                  << "S: * VANISHED (EARLIER) 300:310,405,411"
                  << "S: * 1 FETCH (UID 404 MODSEQ (65402) FLAGS (\\Seen))"
                  << "S: * 2 FETCH (UID 406 MODSEQ (75403) FLAGS (\\Deleted))"
@@ -198,25 +196,26 @@ private Q_SLOTS:
 
         KIMAP::Session session(QStringLiteral("127.0.0.1"), 5989);
 
-        auto *job = new KIMAP::FetchJob(&session);
+        auto job = new KIMAP::FetchJob(&session);
         job->setUidBased(uidBased);
         job->setSequenceSet(set);
         job->setScope(scope);
 
-        connect(job, SIGNAL(headersReceived(QString,
-                                            QMap<qint64, qint64>,
-                                            QMap<qint64, qint64>,
-                                            QMap<qint64, KIMAP::MessageAttribute>,
-                                            QMap<qint64, KIMAP::MessageFlags>,
-                                            QMap<qint64, KIMAP::MessagePtr>)),
-                this, SLOT(onHeadersReceived(QString,
-                                             QMap<qint64, qint64>,
-                                             QMap<qint64, qint64>,
-                                             QMap<qint64, KIMAP::MessageAttribute>,
-                                             QMap<qint64, KIMAP::MessageFlags>,
-                                             QMap<qint64, KIMAP::MessagePtr>)));
-        connect(job, &KIMAP::FetchJob::messagesAvailable,
-                this, &FetchJobTest::onMessagesAvailable);
+        connect(job,
+                SIGNAL(headersReceived(QString,
+                                       QMap<qint64, qint64>,
+                                       QMap<qint64, qint64>,
+                                       QMap<qint64, KIMAP::MessageAttribute>,
+                                       QMap<qint64, KIMAP::MessageFlags>,
+                                       QMap<qint64, KIMAP::MessagePtr>)),
+                this,
+                SLOT(onHeadersReceived(QString,
+                                       QMap<qint64, qint64>,
+                                       QMap<qint64, qint64>,
+                                       QMap<qint64, KIMAP::MessageAttribute>,
+                                       QMap<qint64, KIMAP::MessageFlags>,
+                                       QMap<qint64, KIMAP::MessagePtr>)));
+        connect(job, &KIMAP::FetchJob::messagesAvailable, this, &FetchJobTest::onMessagesAvailable);
 
         QSignalSpy vanishedSpy(job, &KIMAP::FetchJob::messagesVanished);
         QVERIFY(vanishedSpy.isValid());
@@ -252,11 +251,11 @@ private Q_SLOTS:
     void testFetchStructure()
     {
         QList<QByteArray> scenario;
-        scenario << FakeServer::preauth()
-                 << "C: A000001 FETCH 1:2 (BODYSTRUCTURE UID)"
-                 << R"(S: * 1 FETCH (UID 10 BODYSTRUCTURE ("TEXT" "PLAIN" ("CHARSET" "ISO-8859-1") NIL NIL "7BIT" 5 1 NIL NIL NIL)))"
-                 << R"(S: * 2 FETCH (UID 20 BODYSTRUCTURE (((("TEXT" "PLAIN" ("CHARSET" "ISO-8859-1") NIL NIL "7BIT" 72 4 NIL NIL NIL)("TEXT" "HTML" ("CHARSET" "ISO-8859-1") NIL NIL "QUOTED-PRINTABLE" 281 5 NIL NIL NIL) "ALTERNATIVE" ("BOUNDARY" "0001") NIL NIL)("IMAGE" "GIF" ("NAME" "B56.gif") "<B56@goomoji.gmail>" NIL "BASE64" 528 NIL NIL NIL) "RELATED" ("BOUNDARY" "0002") NIL NIL)("IMAGE" "JPEG" ("NAME" "photo.jpg") NIL NIL "BASE64" 53338 NIL ("ATTACHMENT" ("FILENAME" "photo.jpg")) NIL) "MIXED" ("BOUNDARY" "0003") NIL NIL)))"
-                 << "S: A000001 OK fetch done";
+        scenario
+            << FakeServer::preauth() << "C: A000001 FETCH 1:2 (BODYSTRUCTURE UID)"
+            << R"(S: * 1 FETCH (UID 10 BODYSTRUCTURE ("TEXT" "PLAIN" ("CHARSET" "ISO-8859-1") NIL NIL "7BIT" 5 1 NIL NIL NIL)))"
+            << R"(S: * 2 FETCH (UID 20 BODYSTRUCTURE (((("TEXT" "PLAIN" ("CHARSET" "ISO-8859-1") NIL NIL "7BIT" 72 4 NIL NIL NIL)("TEXT" "HTML" ("CHARSET" "ISO-8859-1") NIL NIL "QUOTED-PRINTABLE" 281 5 NIL NIL NIL) "ALTERNATIVE" ("BOUNDARY" "0001") NIL NIL)("IMAGE" "GIF" ("NAME" "B56.gif") "<B56@goomoji.gmail>" NIL "BASE64" 528 NIL NIL NIL) "RELATED" ("BOUNDARY" "0002") NIL NIL)("IMAGE" "JPEG" ("NAME" "photo.jpg") NIL NIL "BASE64" 53338 NIL ("ATTACHMENT" ("FILENAME" "photo.jpg")) NIL) "MIXED" ("BOUNDARY" "0003") NIL NIL)))"
+            << "S: A000001 OK fetch done";
 
         KIMAP::FetchJob::FetchScope scope;
         scope.mode = KIMAP::FetchJob::FetchScope::Structure;
@@ -267,21 +266,16 @@ private Q_SLOTS:
 
         KIMAP::Session session(QStringLiteral("127.0.0.1"), 5989);
 
-        auto *job = new KIMAP::FetchJob(&session);
+        auto job = new KIMAP::FetchJob(&session);
         job->setUidBased(false);
         job->setSequenceSet(KIMAP::ImapSet(1, 2));
         job->setScope(scope);
 
-        connect(job, SIGNAL(messagesReceived(QString,
-                                             QMap<qint64, qint64>,
-                                             QMap<qint64, KIMAP::MessageAttribute>,
-                                             QMap<qint64, KIMAP::MessagePtr>)),
-                this, SLOT(onMessagesReceived(QString,
-                                              QMap<qint64, qint64>,
-                                              QMap<qint64, KIMAP::MessageAttribute>,
-                                              QMap<qint64, KIMAP::MessagePtr>)));
-        connect(job, &KIMAP::FetchJob::messagesAvailable,
-                this, &FetchJobTest::onMessagesAvailable);
+        connect(job,
+                SIGNAL(messagesReceived(QString, QMap<qint64, qint64>, QMap<qint64, KIMAP::MessageAttribute>, QMap<qint64, KIMAP::MessagePtr>)),
+                this,
+                SLOT(onMessagesReceived(QString, QMap<qint64, qint64>, QMap<qint64, KIMAP::MessageAttribute>, QMap<qint64, KIMAP::MessagePtr>)));
+        connect(job, &KIMAP::FetchJob::messagesAvailable, this, &FetchJobTest::onMessagesAvailable);
 
         bool result = job->exec();
         QVERIFY(result);
@@ -297,8 +291,7 @@ private Q_SLOTS:
         QCOMPARE(m_msgs[2].message->attachments().count(), 1);
         QCOMPARE(m_msgs[2].message->contents().size(), 2);
         QCOMPARE(m_msgs[2].message->contents()[0]->contents().size(), 2);
-        QCOMPARE(m_msgs[2].message->attachments().at(0)->contentDisposition()->filename(),
-                 QStringLiteral("photo.jpg"));
+        QCOMPARE(m_msgs[2].message->attachments().at(0)->contentDisposition()->filename(), QStringLiteral("photo.jpg"));
 
         fakeServer.quit();
 
@@ -316,8 +309,12 @@ private Q_SLOTS:
     {
         QList<QByteArray> scenario;
         scenario << FakeServer::preauth()
-                 << "C: A000001 FETCH 2 (BODY.PEEK[HEADER.FIELDS (TO FROM MESSAGE-ID REFERENCES IN-REPLY-TO SUBJECT DATE)] BODY.PEEK[1.1.1.MIME] BODY.PEEK[1.1.1] FLAGS UID)"
-                 << "S: * 2 FETCH (UID 20 FLAGS (\\Seen) BODY[HEADER.FIELDS (TO FROM MESSAGE-ID REFERENCES IN-REPLY-TO SUBJECT DATE)] {154}\r\nFrom: Joe Smith <smith@example.com>\r\nDate: Wed, 2 Mar 2011 11:33:24 +0700\r\nMessage-ID: <1234@example.com>\r\nSubject: hello\r\nTo: Jane <jane@example.com>\r\n\r\n BODY[1.1.1] {28}\r\nHi Jane, nice to meet you!\r\n BODY[1.1.1.MIME] {48}\r\nContent-Type: text/plain; charset=ISO-8859-1\r\n\r\n)\r\n"
+                 << "C: A000001 FETCH 2 (BODY.PEEK[HEADER.FIELDS (TO FROM MESSAGE-ID REFERENCES IN-REPLY-TO SUBJECT DATE)] BODY.PEEK[1.1.1.MIME] "
+                    "BODY.PEEK[1.1.1] FLAGS UID)"
+                 << "S: * 2 FETCH (UID 20 FLAGS (\\Seen) BODY[HEADER.FIELDS (TO FROM MESSAGE-ID REFERENCES IN-REPLY-TO SUBJECT DATE)] {154}\r\nFrom: Joe Smith "
+                    "<smith@example.com>\r\nDate: Wed, 2 Mar 2011 11:33:24 +0700\r\nMessage-ID: <1234@example.com>\r\nSubject: hello\r\nTo: Jane "
+                    "<jane@example.com>\r\n\r\n BODY[1.1.1] {28}\r\nHi Jane, nice to meet you!\r\n BODY[1.1.1.MIME] {48}\r\nContent-Type: text/plain; "
+                    "charset=ISO-8859-1\r\n\r\n)\r\n"
                  << "S: A000001 OK fetch done";
 
         KIMAP::FetchJob::FetchScope scope;
@@ -331,33 +328,30 @@ private Q_SLOTS:
 
         KIMAP::Session session(QStringLiteral("127.0.0.1"), 5989);
 
-        auto *job = new KIMAP::FetchJob(&session);
+        auto job = new KIMAP::FetchJob(&session);
         job->setUidBased(false);
         job->setSequenceSet(KIMAP::ImapSet(2, 2));
         job->setScope(scope);
 
-        connect(job, SIGNAL(headersReceived(QString,
-                                            QMap<qint64, qint64>,
-                                            QMap<qint64, qint64>,
-                                            QMap<qint64, KIMAP::MessageAttribute>,
-                                            QMap<qint64, KIMAP::MessageFlags>,
-                                            QMap<qint64, KIMAP::MessagePtr>)),
-                this, SLOT(onHeadersReceived(QString,
-                                             QMap<qint64, qint64>,
-                                             QMap<qint64, qint64>,
-                                             QMap<qint64, KIMAP::MessageAttribute>,
-                                             QMap<qint64, KIMAP::MessageFlags>,
-                                             QMap<qint64, KIMAP::MessagePtr>)));
-        connect(job, SIGNAL(partsReceived(QString,
-                                          QMap<qint64, qint64>,
-                                          QMap<qint64, KIMAP::MessageAttribute>,
-                                          QMap<qint64, KIMAP::MessageParts>)),
-                this, SLOT(onPartsReceived(QString,
-                                           QMap<qint64, qint64>,
-                                           QMap<qint64, KIMAP::MessageAttribute>,
-                                           QMap<qint64, KIMAP::MessageParts>)));
-        connect(job, &KIMAP::FetchJob::messagesAvailable,
-                this, &FetchJobTest::onMessagesAvailable);
+        connect(job,
+                SIGNAL(headersReceived(QString,
+                                       QMap<qint64, qint64>,
+                                       QMap<qint64, qint64>,
+                                       QMap<qint64, KIMAP::MessageAttribute>,
+                                       QMap<qint64, KIMAP::MessageFlags>,
+                                       QMap<qint64, KIMAP::MessagePtr>)),
+                this,
+                SLOT(onHeadersReceived(QString,
+                                       QMap<qint64, qint64>,
+                                       QMap<qint64, qint64>,
+                                       QMap<qint64, KIMAP::MessageAttribute>,
+                                       QMap<qint64, KIMAP::MessageFlags>,
+                                       QMap<qint64, KIMAP::MessagePtr>)));
+        connect(job,
+                SIGNAL(partsReceived(QString, QMap<qint64, qint64>, QMap<qint64, KIMAP::MessageAttribute>, QMap<qint64, KIMAP::MessageParts>)),
+                this,
+                SLOT(onPartsReceived(QString, QMap<qint64, qint64>, QMap<qint64, KIMAP::MessageAttribute>, QMap<qint64, KIMAP::MessageParts>)));
+        connect(job, &KIMAP::FetchJob::messagesAvailable, this, &FetchJobTest::onMessagesAvailable);
         bool result = job->exec();
 
         QVERIFY(result);
@@ -387,11 +381,10 @@ private Q_SLOTS:
         QByteArray partId = m_parts[2].keys().first();
         QString text = m_parts[2].value(partId)->decodedText(true, true);
         QCOMPARE(partId, QByteArray("1.1.1"));
-        QCOMPARE(text, QStringLiteral("Hi Jane, nice to meet you!")) ;
+        QCOMPARE(text, QStringLiteral("Hi Jane, nice to meet you!"));
 
         QCOMPARE(m_msgs[2].parts.keys().first(), QByteArray("1.1.1"));
-        QCOMPARE(m_msgs[2].parts.value(partId)->decodedText(true, true),
-                 QStringLiteral("Hi Jane, nice to meet you!"));
+        QCOMPARE(m_msgs[2].parts.value(partId)->decodedText(true, true), QStringLiteral("Hi Jane, nice to meet you!"));
 
         fakeServer.quit();
 
@@ -404,7 +397,6 @@ private Q_SLOTS:
         m_attrs.clear();
         m_msgs.clear();
     }
-
 };
 
 QTEST_GUILESS_MAIN(FetchJobTest)
